@@ -149,7 +149,7 @@ class DB(object):
         assert lessonfile.is_uri(filename) or os.path.isabs(filename), filename
         row = self.conn.execute(
                 "select fileid from lessonfiles "
-                "where filename=?", 
+                "where filename=?",
                 (filename,)).fetchone()
         if row:
             return row[0]
@@ -197,7 +197,7 @@ class DB(object):
         def load(file):
             unpickler = pickle.Unpickler(file)
             unpickler.dispatch[pickle.GLOBAL] = mapped_load_global
-            return unpickler.load() 
+            return unpickler.load()
 
         imp, uuid_to_filename = self.get_uuid_to_filename_mapping(callback)
         def read_session_data(datadir, is_tests, counter):
@@ -368,7 +368,7 @@ class DB(object):
                     self.cache_new_test_result(filename, timestamp,
                         p.get_test_requirement(), p.get_test_num_questions())
         self.set_variable("database_version", 2)
-    def cache_new_test_result(self, filename, timestamp, 
+    def cache_new_test_result(self, filename, timestamp,
                               required, num_questions):
         """
         Save the test result in the "lessonfiles" table for faster
@@ -445,7 +445,7 @@ class DB(object):
                     replaces = [replaces]
                 if not hashvalue in replaces:
                     cursor.execute("delete from sessions where fileid=?", (fileid,))
-                    cursor.execute("delete from sessioninfo where fileid=?", (fileid,)) 
+                    cursor.execute("delete from sessioninfo where fileid=?", (fileid,))
                     cursor.execute("update lessonfiles "
                         "set hash=?, test_passed=?, test_result=0.0 where fileid=?",
                         (cur_lessonfile_hash_value, None, fileid))
@@ -526,7 +526,7 @@ class DB(object):
         """
         cursor = self.conn.execute('delete from variables where variable_name=?', (name,))
         if not cursor.rowcount:
-            # rowcount is 0 if no variables where deleted. We raise an 
+            # rowcount is 0 if no variables where deleted. We raise an
             # error, since I'd like to know if we tries to do this.
             raise self.VariableUndefinedError()
 
@@ -591,8 +591,8 @@ class AbstractStatistics(object):
             q = solfege.db.conn.execute("select answerkey, guessed, sum(count) from sessions where fileid=? and timestamp>? group by answerkey, guessed", (fileid, self.m_timestamp - seconds))
         ret = {}
         for answer, guess, count in q.fetchall():
-            ret.setdefault(self.int_if_int(answer), {})
-            ret[self.int_if_int(answer)][self.int_if_int(guess)] = count
+            ret.setdefault(answer, {})
+            ret[answer][guess] = count
         return ret
     def reset_session(self):
         """
@@ -618,7 +618,9 @@ class AbstractStatistics(object):
         Register that for the question 'question' the user answered 'answer'.
         """
         assert self.m_timestamp
-        # tuples must be converted to str to store them in sqlite.
+        # tuples must be converted to str to store them in sqlite. Integers
+        # and probably some other types will automatically be converted to
+        # strings by sqlite before storing then in the database.
         if isinstance(question, tuple):
             question = str(question)
         if isinstance(answer, tuple):
@@ -644,7 +646,7 @@ class AbstractStatistics(object):
                 "insert into sessions "
                 "(fileid, timestamp, answerkey, guessed, count) "
                 "values(?, ?, ?, ?, ?)",
-                (fileid, self.m_timestamp, 
+                (fileid, self.m_timestamp,
                  unicode(question), unicode(answer), 1))
         else:
             assert cursor.fetchone() is None
@@ -759,7 +761,9 @@ class IntervalStatistics(AbstractStatistics):
     def get_keys(self, all_keys=False):
         # FIXME we have to check that all keys are integers, and filter
         # out those that are not. I don't know how, but I ended up with
-        # the key None inserted into the database.
+        # the key None inserted into the database. Without that bug this
+        # whole method would be unnecessary and AbstractStatistics.get_keys
+        # would be enough.
         def isinteger(s):
             try:
                 int(s)
@@ -767,7 +771,7 @@ class IntervalStatistics(AbstractStatistics):
             except ValueError:
                 return False
         v = AbstractStatistics.get_keys(self, all_keys)
-        return [int(x) for x in v if isinteger(x)]
+        return [x for x in v if isinteger(x)]
     def key_to_pretty_name(self, key):
         return utils.int_to_intervalname(int(key), 1, 1)
 
